package org.rcisoft.bus.ossinfo.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.aop.CyPageUtilAsp;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.bus.ossinfo.dao.OssInfoRepository;
import org.rcisoft.bus.ossinfo.entity.OssInfo;
import org.rcisoft.bus.ossinfo.service.OssInfoService;
import org.rcisoft.core.service.CyBaseService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.rcisoft.core.model.CyPageInfo;

import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by cy on 2024年5月27日 下午3:19:03.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class OssInfoServiceImpl extends ServiceImpl<OssInfoRepository,OssInfo>  implements OssInfoService {


    /**
    * 保存
    * @param ossInfo
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(OssInfo ossInfo){
        //增加操作
        int line = baseMapper.insert(ossInfo);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            ossInfo.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除
    * @param ossInfo
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(OssInfo ossInfo){
        ossInfo.setDeleted();
        int line = baseMapper.deleteById(ossInfo);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            ossInfo.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }

    /**
    * 修改
    * @param ossInfo
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(OssInfo ossInfo){
        int line = baseMapper.updateById(ossInfo);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ ossInfo.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询
    * @param id
    * @return
    */
    @Override
    public OssInfo findById(int id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询
    * @param ossInfo
    * @return
    */
    @Override
    public IPage<OssInfo> findAllByPagination(CyPageInfo<OssInfo> paginationUtility,
        OssInfo ossInfo){
        return baseMapper.queryOssInfosPaged(paginationUtility,ossInfo);

    }

    /**
    * 查询list
    * @param ossInfo
    * @return
    */
    @Override
    public List<OssInfo> findAll(OssInfo ossInfo){
        return baseMapper.queryOssInfos(ossInfo);

    }

    /**
    * 导出
    * @return
    */
    @Override
    public List<OssInfo> export(OssInfo ossInfo) {
        List<OssInfo> ossInfoList = baseMapper.queryOssInfos(ossInfo);
        return ossInfoList;
    }

}
